Ref<A> class
Reference use to store arguments before create an Element and listen when an Element has been disposed
Properties
- arguments → A
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- providerLabel → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String?
-
final
Methods
-
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onDispose(
void callback()) → void -
setArguments(
A args) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited